@@ -290,7 +290,8 @@ class LaharFlowData(object):
 
     def _get_parameters_from_inputfile(self):
         if self.zipped:
-            inputFilePath = _path_of_file_in_zip(self.inputFile,self._zipref)[0]
+            inputFileName = os.path.split(self.inputFile)[-1]
+            inputFilePath = _path_of_file_in_zip(inputFileName, self._zipref)[0]
             inputFile = self._zipref.extract(inputFilePath,path=self.dir)
         else:
             inputFile = os.path.join(self.dir,os.path.split(self.inputFile)[1])
